%define         enable_checks            0

%define         major                    3
%define         libname                  %mklibname %{name} %{major}
%define         develname                %mklibname %{name} -d
%define         staticdevelname          %mklibname %{name} -d -s

%define         libmpiname               %mklibname %{name}mpi %{major}
%define         libompname               %mklibname %{name}omp %{major}

Summary:        Fast Fourier transform library
Name:           fftw
Version:        3.3.10
Release:        %mkrel 1
License:        GPLv2+
Group:          System/Libraries

URL:            http://www.fftw.org
Source:         ftp://ftp.fftw.org/pub/fftw/%{name}-%{version}.tar.xz
BuildRequires:  gcc-gfortran
%ifarch %ix86 x86_64
BuildRequires:  quadmath-devel
%endif
BuildRequires:  libgomp-devel
BuildRequires:  lib64openmpi-devel
BuildRequires:  openmpi
BuildRequires:  perl

%description
FFTW is a collection of fast C routines for computing the Discrete
Fourier Transform in one or more dimensions. It includes complex,
real, and parallel transforms, can handle arbitrary array sizes
efficiently and can be called from Fortran.

%package wisdom
Summary:        FFTW-wisdom file generator
Group:          Development/Other

%description wisdom
This package contains a wisdom file generator to be used with the FFTW
Fourier transform library. These files contain saved information about how
to optimally compute transforms of various sizes.



%package -n %{libname}
Summary:        Fast Fourier transform library
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}


%description -n %{libname}
FFTW is a collection of fast C routines for computing the Discrete Fourier
Transform in one or more dimensions.  It includes complex, real, and
parallel transforms, and can handle arbitrary array sizes efficiently.



%package -n %{libmpiname}
Summary:        MPI-parallel fast Fourier transform library
Group:          System/Libraries
Provides:       %{name}-mpi = %{version}-%{release}

%description -n %{libmpiname}
%{summary}.



%package -n %{libompname}
Summary:        OpenMP-parallel fast Fourier transform library
Group:          System/Libraries
Provides:       %{name}-openmp = %{version}-%{release}
Provides:       %{name}-omp = %{version}-%{release}

%description -n %{libompname}
%{summary}.



%package -n %{develname}
Summary:        Headers, libraries, & docs for the FFTW fast Fourier transform library
Group:          Development/Libraries
Requires:       lib64openmpi-devel
Requires:       %{libname} = %{version}-%{release}
Requires:       %{libompname} = %{version}-%{release}
Requires:       %{libmpiname} = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}
Provides:       %{name}%{major}-devel = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
This package contains the additional header files, documentation, and
libraries you need to develop programs using the FFTW fast Fourier
transform library.


%package -n %{staticdevelname}
Summary:        Static development files for the FFTW fast Fourier transform library
Group:          Development/Libraries
Requires:       %{libname} = %{version}-%{release}
Requires:       lib%{name}-devel = %{version}-%{release}
Provides:       lib%{name}-static-devel = %{version}-%{release}

%description -n %{staticdevelname}
%{summary}.


%prep
%setup -q

%build
export F77="gfortran"
export MPILIBS="-lmpi"
export LDFLAGS="-L/usr/lib64/libglvnd/ $LDFLAGS"

if [ ! -d build-std ]; then
        mkdir build-std
fi
pushd build-std
CONFIGURE_TOP=.. %configure2_5x \
                    --enable-shared \
                    --enable-threads \
                    --enable-openmp \
                    --enable-mpi \
                    --enable-fortran \
                    %ifarch x86_64
                    --enable-sse2 \
                    --enable-avx \
                    %endif
                    --infodir=%{_infodir}

%make_build
popd

if [ ! -d build-float ]; then
        mkdir build-float
fi
pushd build-float
CONFIGURE_TOP=.. %configure2_5x \
                    --enable-float \
                    --enable-shared \
                    --enable-threads \
                    --enable-openmp \
                    --enable-mpi \
                    --enable-fortran \
                    %ifarch x86_64
                    --enable-sse2 \
                    --enable-avx \
                    %endif
                    --infodir=%{_infodir}
%make_build
popd

#SSE2 and AVX do not work with long-double
if [ ! -d build-long-double ]; then
        mkdir build-long-double
fi
pushd build-long-double
CONFIGURE_TOP=.. %configure2_5x \
                    --enable-long-double \
                    --enable-shared \
                    --enable-threads \
                    --enable-openmp \
                    --enable-mpi \
                    --enable-fortran \
                    --infodir=%{_infodir}
%make_build
popd

%ifarch %{ix86} x86_64
#SSE2,AVX, and MPI do not work with quad-precision
mkdir build-quad-precision
pushd build-quad-precision
CONFIGURE_TOP=.. %configure2_5x \
                    --enable-quad-precision \
                    --enable-shared \
                    --enable-threads \
                    --enable-openmp \
                    --enable-fortran \
                    --infodir=%{_infodir}
%make_build
%endif


%install
rm -rf %buildroot
pushd build-std
%make_install
popd
pushd build-float
%make_install
popd
pushd build-long-double
%make_install
popd
%ifarch %{ix86} x86_64
pushd build-quad-precision
%make_install
popd
%endif

rm -fr %{buildroot}/%{_docdir}/Make*
find %{buildroot}%{_libdir} -name *.la -delete

%files -n %{name}-wisdom
%{_bindir}/fftw*-wisdom
%{_bindir}/fftw-wisdom-to-conf
%{_mandir}/man1/fftw-wisdom-to-conf.*
%{_mandir}/man1/fftw*-wisdom.*


%files -n %{libname}
%{_libdir}/libfftw3.so.%{major}*
%{_libdir}/libfftw3f.so.%{major}*
%{_libdir}/libfftw3l.so.%{major}*
%ifarch %{ix86} x86_64
%{_libdir}/libfftw3q.so.%{major}*
%endif
%{_libdir}/libfftw3*_threads.so.%{major}*


%files -n %{libmpiname}
%{_libdir}/libfftw3*_mpi.so.%{major}*


%files -n %{libompname}
%{_libdir}/libfftw3*_omp.so.%{major}*


%files -n %{develname}
%doc ChangeLog doc/*
%{_includedir}/*fftw*.h
%{_includedir}/fftw3*.f*
%{_infodir}/fftw%{major}.info*
%{_libdir}/pkgconfig/*.pc
%{_libdir}/libfftw*.so
%{_libdir}/cmake/fftw3/

%files -n %{staticdevelname}
%{_libdir}/libfftw*.a

%changelog
* Fri Jul 08 2022 onkelho <oh.quait at gmail.com> - 3.3.10-1pclos2022
- new version

* Tue Dec 29 2020 tex - 3.3.8-1pclos2021
- new version

* Fri Apr 20 2018 bb2 <bb2> - 3.3.7-1pclos2018
- new version

* Fri Apr 07 2017 bb2 <bb2> - 3.3.6-1pclos2017
- update

